@@ -1,7 +1,7 @@
 package Finance::Robinhood::Order;
 use 5.010;
 use Carp;
-our $VERSION = "0.18";
+our $VERSION = "0.19";
 use Moo;
 use strictures 2;
 use namespace::clean;
@@ -9,7 +9,9 @@ require Finance::Robinhood;
 #
 has $_ => (is => 'ro', required => 1)
     for (qw[average_price id cumulative_quantity fees price quantity
-         reject_reason side state stop_price time_in_force trigger type url]);
+         override_dtbp_checks extended_hours override_day_trade_checks
+         reject_reason side state stop_price time_in_force trigger type url]
+    );
 has $_ => (is       => 'ro',
            required => 1,
            coerce   => \&Finance::Robinhood::_2_datetime
@@ -39,6 +41,11 @@ around BUILDARGS => sub {
             {account    => {@args}->{account}->_get_url(),
              instrument => {@args}->{instrument}->url(),
              symbol     => {@args}->{instrument}->symbol(),
+             (map {
+                  {@args}
+                  ->{$_} ? ($_ => ({@args}->{$_} ? 'true' : 'false')) : ()
+              } qw[override_dtbp_checks extended_hours override_day_trade_checks]
+             ),
              (map {
                   {@args}
                   ->{$_} ? ($_ => {@args}->{$_}) : ()
@@ -104,6 +111,10 @@ sub position {
         : ();
 }
 
+sub _can_cancel {
+    shift->_get_cancel ? 1 : 0;
+}
+
 sub cancel {
     my ($self) = @_;
     my $can_cancel = $self->_get_cancel();
@@ -145,7 +156,7 @@ Finance::Robinhood::Order - Order to Buy or Sell a Security
 =head1 DESCRIPTION
 
 This class represents a single buy or sell order. These are returned by the
-C<locate_order( ... )> and C<list_order( ... )> methods of Finance::Robinhood.
+C<locate_order( ... )> and C<list_orders( ... )> methods of Finance::Robinhood.
 
 Of course, you may place new orders with the C<new( ... )> constructor of this
 class.
@@ -298,6 +309,21 @@ C<stop_price>. I obviously would not modify your orders to comply!
 Please note that the API wants prices including C<stop_price> to be I<at most>
 4 decimal places. It is your responsibility to make sure of that.
 
+=item C<override_dtbp_checks>
+
+This tells Robinhood's API servers to accept the order even if it violates the
+Day-Trade Bying Power limits.
+
+=item C<extended_hours>
+
+This tells the API server to accept the order after the markets are closed. If
+you'd like these to execute after hours, you must set the type to 'limit' and
+have a Robinhood Gold subscription.
+
+=item C<override_day_trade_checks>
+
+This overrides the API's Pattern Day Trade Protection warnings.
+
 =back
 
 =head2 C<account( )>
@@ -413,6 +439,18 @@ The timestamp of the most recent execution.
 
 Timestamp of the last change made to this order.
 
+=head2 C<override_dtbp_checks( )>
+
+True if the Day-Trading Buying Power checks are turned off.
+
+=head2 C<extended_hours( )>
+
+Returns true if the order is set to execute after hours.
+
+=head2 C<override_day_trade_checks( )>
+
+Returns true if the Pattern Day Trade checks are disabled.
+
 =head1 Order Cheat Sheet
 
 This is a little cheat sheet for creating certain types of orders:
