@@ -1,14 +1,15 @@
 package Finance::Robinhood::Position;
 use 5.010;
 use Carp;
-our $VERSION = "0.18";
+our $VERSION = "0.19";
 use Moo;
 use strictures 2;
 use namespace::clean;
 require Finance::Robinhood;
 #
 has $_ => (is => 'ro', required => 1)
-    for (qw[average_buy_price intraday_quantity quantity
+    for (qw[intraday_average_buy_price average_buy_price
+         intraday_quantity quantity
          shares_held_for_buys shares_held_for_sells url]);
 has $_ => (is       => 'ro',
            required => 1,
@@ -64,6 +65,10 @@ Returns the Finance::Robinhood::Account object related to this order.
 
 How much you spent on average for shares of this security.
 
+=head2 C<intraday_average_buy_price( )>
+
+
+
 =head2 C<created_at( )>
 
 Timestamp of your first buy of this this security.
